@@ -173,7 +173,7 @@ init (GnomePilotCapplet *gpcap)
 		g_message ("gnome-pilot-capplet init(): Could not load the Glade XML file!");
 		goto error;
 	}
-
+	
 	if (!get_widgets (gpcap)) {
 		g_message ("gnome-pilot-capplet init(): Could not find all widgets in the XML file!");
 		goto error;
@@ -183,6 +183,7 @@ init (GnomePilotCapplet *gpcap)
 	init_widgets (gpcap);
 
  error:
+	;
 }
 
 GnomePilotCapplet *
@@ -208,6 +209,8 @@ get_widgets (GnomePilotCapplet *gpcap)
 #define GW(name) glade_xml_get_widget (priv->xml, name)
 
 	gtk_window_set_title (GTK_WINDOW (gpcap), _("Pilot Settings"));
+	gtk_dialog_add_button (GTK_DIALOG (gpcap),
+			       GTK_STOCK_HELP, GTK_RESPONSE_HELP);
 	gtk_dialog_add_button (GTK_DIALOG (gpcap),
 			       GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 
