@@ -26,6 +26,7 @@
 
 #include <config.h>
 #include <gnome.h>
+#include <pi-util.h>
 
 #include "pilot.h"
 
@@ -60,7 +61,6 @@ copy_pilot (GPilotPilot *pilot, PilotState *dest)
     pilot2->pilot_id = pilot->pilot_id;
     pilot2->creation = pilot->creation;
     pilot2->romversion = pilot->romversion;
-    pilot2->sync_options.default_sync_action = pilot->sync_options.default_sync_action;
     pilot2->sync_options.basedir = g_strdup (pilot->sync_options.basedir);
     dest->pilots = g_list_append (dest->pilots, pilot2);
 }
@@ -182,6 +182,7 @@ loadPilotPilot (PilotState *p)
   GPilotPilot *pilot;
   gboolean notfound;
   gchar *prefix;
+  char *local_name;
   int i, num;
 
   gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
@@ -194,7 +195,6 @@ loadPilotPilot (PilotState *p)
       return -1;
   } else {
 	  for (i=0;i<num;i++){
-		  gchar *tmp;
 		  pilot = g_new0(GPilotPilot, 1);
 		  prefix = g_strdup_printf ("/gnome-pilot.d/gpilotd/Pilot%d/", i);
 		  gnome_config_push_prefix (prefix);
@@ -204,7 +204,11 @@ loadPilotPilot (PilotState *p)
 		  if (notfound)
 			  pilot->pilot_id = getuid ();
 		  g_message ("Pilot id   -> %d", pilot->pilot_id);
-		  pilot->pilot_username = gnome_config_get_string ("pilotusername");
+		  local_name = gnome_config_get_string ("pilotusername");
+		  if (!local_name || (convert_FromPilotChar ("UTF-8", local_name, strlen(local_name), &pilot->pilot_username) == -1)) {
+  		  	pilot->pilot_username = g_strdup (local_name);
+		  }
+		  g_free (local_name);
 		  g_message ("Pilot username -> %s", pilot->pilot_username);
 	  
 		  pilot->creation = gnome_config_get_int ("creation");
@@ -212,12 +216,6 @@ loadPilotPilot (PilotState *p)
 		  
 		  g_message ("Pilot creation/rom = %lu/%lu", pilot->creation, pilot->romversion);
 
-		  tmp = gnome_config_get_string ("default_sync_action=custom");
-		  g_message ("Pilot sync_action -> %s", tmp);
-		  pilot->sync_options.default_sync_action = gnome_pilot_conduit_sync_type_str_to_int (tmp);
-		  g_free (tmp);
-
-
 		  pilot->sync_options.basedir = gnome_config_get_string ("basedir");
 		  if (pilot->sync_options.basedir==NULL) {
 			  pilot->sync_options.basedir = g_strdup_printf ("%s/%s", g_get_home_dir (), pilot->name);
@@ -268,6 +266,7 @@ savePilotState (PilotState *state)
   int i;
   GList *tmp;
   gchar *prefix;
+  char *local_name;
 
   gnome_config_clean_section ("/gnome-pilot.d/gpilotd/General/");
 
@@ -318,9 +317,11 @@ savePilotState (PilotState *state)
 	  gnome_config_set_int ("pilotid", pilot->pilot_id);
 	  gnome_config_set_int ("creation", pilot->creation);
 	  gnome_config_set_int ("romversion", pilot->romversion);
-	  gnome_config_set_string ("pilotusername", pilot->pilot_username);
-	  gnome_config_set_string ("default_sync_action", 
-				  gnome_pilot_conduit_sync_type_int_to_str (pilot->sync_options.default_sync_action));
+	  if (!pilot->pilot_username|| (convert_ToPilotChar ("UTF-8", pilot->pilot_username, strlen (pilot->pilot_username),&local_name) == -1)) {
+		  local_name = g_strdup (pilot->pilot_username);
+	  }
+	  gnome_config_set_string ("pilotusername", local_name);
+	  g_free (local_name);
 	  gnome_config_set_string ("basedir", pilot->sync_options.basedir);
 	  gnome_config_pop_prefix ();
 	  g_free (prefix);
