@@ -28,6 +28,7 @@
 #include <pi-socket.h>
 #include <pi-dlp.h>
 #include "gnome-pilot-conduit-standard-abs.h"
+#include "gpmarshal.h"
 #include "manager.h"
 
 enum {
@@ -62,9 +63,9 @@ typedef enum StandardAbsSyncDirection StandardAbsSyncDirection;
 #define LOG_CASE5 _("deleted pilot record modified locally, not deleting\n")
 #define LOG_CASE6 _("deleted local record modified on pilot, not deleting\n")
 #define LOG_CASE10 _("merge conflict, pilot and local record swapped\n")
-#define LOG_CASE13 _("arhive and change conflict, pilot and local record swapped\n")
-#define LOG_CASE15 _("arhive and change conflict, local record sent to pilot\n")
-#define LOG_CASE18 _("arhive and change conflict, pilot record saved locally\n")
+#define LOG_CASE13 _("archive and change conflict, pilot and local record swapped\n")
+#define LOG_CASE15 _("archive and change conflict, local record sent to pilot\n")
+#define LOG_CASE18 _("archive and change conflict, pilot record saved locally\n")
 #define LOG_CASE20 _("merge conflict, pilot and local record swapped\n")
 
 #define Result(v) result = v; break
@@ -142,87 +143,6 @@ gnome_pilot_conduit_standard_abs_new (char *db_name,
 	return retval;
 }
 
-/* We have a bunch of marshalling functions that we need to declare.
- * We do so here */
-typedef gint (*GtkSignal_INT__POINTER_POINTER) (GtkObject * object,
-						gpointer arg1,
-						gpointer arg2,
-						gpointer user_data);
-static void
-gtk_marshal_INT__POINTER_POINTER (GtkObject * object,
-				  GtkSignalFunc func,
-				  gpointer func_data,
-				  GtkArg * args)
-{
-	GtkSignal_INT__POINTER_POINTER rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT (args[2]);
-	rfunc = (GtkSignal_INT__POINTER_POINTER) func;
-	*return_val = (*rfunc) (object,
-				GTK_VALUE_POINTER (args[0]),
-				GTK_VALUE_POINTER (args[1]),
-				func_data);
-}
-
-typedef gint (*GtkSignal_INT__POINTER_INT) (GtkObject * object,
-					    gpointer arg1,
-					    gint arg2,
-					    gpointer user_data);
-static void
-gtk_marshal_INT__POINTER_INT (GtkObject * object,
-			      GtkSignalFunc func,
-			      gpointer func_data,
-			      GtkArg * args)
-{
-	GtkSignal_INT__POINTER_INT rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT (args[2]);
-	rfunc = (GtkSignal_INT__POINTER_INT) func;
-	*return_val = (*rfunc) (object,
-				GTK_VALUE_POINTER (args[0]),
-				GTK_VALUE_INT (args[1]),
-				func_data);
-}
-
-typedef gint (*GtkSignal_INT__POINTER_INT_INT) (GtkObject * object,
-						gpointer arg1,
-						gint arg2,
-						gint arg3,
-						gpointer user_data);
-static void
-gtk_marshal_INT__POINTER_INT_INT (GtkObject * object,
-				  GtkSignalFunc func,
-				  gpointer func_data,
-				  GtkArg * args)
-{
-	GtkSignal_INT__POINTER_INT_INT rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT (args[3]);
-	rfunc = (GtkSignal_INT__POINTER_INT_INT) func;
-	*return_val = (*rfunc) (object,
-				GTK_VALUE_POINTER (args[0]),
-				GTK_VALUE_INT (args[1]),
-				GTK_VALUE_INT (args[2]),
-				func_data);
-}
-
-
-typedef gint (*GtkSignal_INT__NONE) (GtkObject * object,
-				     gpointer user_data);
-static void
-gtk_marshal_INT__NONE (GtkObject * object,
-		       GtkSignalFunc func,
-		       gpointer func_data,
-		       GtkArg * args)
-{
-	GtkSignal_INT__NONE rfunc;
-	gint *return_val;
-	return_val = GTK_RETLOC_INT (args[0]);
-	rfunc = (GtkSignal_INT__NONE) func;
-	*return_val = (*rfunc) (object,
-				func_data);
-}
-
 static void
 gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *klass)
 {
@@ -239,7 +159,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, match_record),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[FREE_MATCH] =
@@ -247,7 +167,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, free_match),
-				gtk_marshal_INT__POINTER,
+				gp_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ARCHIVE_LOCAL] =
@@ -255,7 +175,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, archive_local),
-				gtk_marshal_INT__POINTER,
+				gp_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ARCHIVE_REMOTE] =
@@ -263,7 +183,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, archive_remote),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[STORE_REMOTE] =
@@ -271,7 +191,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, store_remote),
-				gtk_marshal_INT__POINTER,
+				gp_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ITERATE] =
@@ -279,7 +199,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, iterate),
-				gtk_marshal_INT__POINTER,
+				gp_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ITERATE_SPECIFIC] =
@@ -287,7 +207,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, iterate_specific),
-				gtk_marshal_INT__POINTER_INT_INT,
+				gp_marshal_INT__POINTER_INT_INT,
 				GTK_TYPE_INT, 3, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_INT);
 
 	pilot_conduit_standard_abs_signals[PURGE] =
@@ -295,7 +215,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, purge),
-				gtk_marshal_INT__NONE,
+				gp_marshal_INT__NONE,
 				GTK_TYPE_INT, 0);
 
 	pilot_conduit_standard_abs_signals[SET_STATUS] =
@@ -303,7 +223,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, set_status),
-				gtk_marshal_INT__POINTER_INT,
+				gp_marshal_INT__POINTER_INT,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
 
 	pilot_conduit_standard_abs_signals[SET_PILOT_ID] =
@@ -311,7 +231,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, set_pilot_id),
-				gtk_marshal_INT__POINTER_INT,
+				gp_marshal_INT__POINTER_INT,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
 
 	pilot_conduit_standard_abs_signals[COMPARE] =
@@ -319,7 +239,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, compare),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[COMPARE_BACKUP] =
@@ -327,7 +247,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, compare_backup),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[FREE_TRANSMIT] =
@@ -335,7 +255,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, free_transmit),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[DELETE_ALL] =
@@ -343,7 +263,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, delete_all),
-				gtk_marshal_INT__NONE,
+				gp_marshal_INT__NONE,
 				GTK_TYPE_INT, 0);
 
 	pilot_conduit_standard_abs_signals[TRANSMIT] =
@@ -351,7 +271,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, transmit),
-				gtk_marshal_INT__POINTER_POINTER,
+				gp_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[PRE_SYNC] =
@@ -359,7 +279,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 				GTK_RUN_LAST,
 				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, pre_sync),
-				gtk_marshal_INT__POINTER,
+				gp_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
 
 	conduit_standard_class->copy_to_pilot = gnome_pilot_conduit_standard_real_copy_to_pilot;
